[chronojump] All the "repetitiveConditions" stuff renamed "feedback"
- From: Xavier de Blas <xaviblas src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [chronojump] All the "repetitiveConditions" stuff renamed "feedback"
- Date: Mon, 21 Mar 2022 09:51:08 +0000 (UTC)
commit e0dd6ed527dc572ac7c480c565e19cd3e0bcafef
Author: Xavier de Blas <xaviblas gmail com>
Date: Mon Mar 21 10:50:31 2022 +0100
All the "repetitiveConditions" stuff renamed "feedback"
...{repetitive_conditions.glade => feedback.glade} | 2 +-
src/Makefile.am | 4 +-
src/execute/event.cs | 2 +-
src/execute/jump.cs | 4 +-
src/execute/run.cs | 4 +-
src/gui/app1/chronojump.cs | 105 +++++++++++----------
src/gui/app1/encoder.cs | 30 +++---
src/gui/encoderGraphObjects.cs | 18 ++--
src/gui/encoderTreeviews.cs | 88 ++++++++---------
src/gui/eventExecute.cs | 12 +--
src/gui/{repetitiveConditions.cs => feedback.cs} | 48 +++++-----
src/gui/networks.cs | 18 ++--
src/gui/usefulObjects.cs | 6 +-
13 files changed, 174 insertions(+), 167 deletions(-)
---
diff --git a/glade/repetitive_conditions.glade b/glade/feedback.glade
similarity index 99%
rename from glade/repetitive_conditions.glade
rename to glade/feedback.glade
index d735650e0..d11645075 100644
--- a/glade/repetitive_conditions.glade
+++ b/glade/feedback.glade
@@ -2,7 +2,7 @@
<glade-interface>
<!-- interface-requires gtk+ 3.0 -->
<!-- interface-naming-policy toplevel-contextual -->
- <widget class="GtkWindow" id="repetitive_conditions">
+ <widget class="GtkWindow" id="feedback">
<property name="can_focus">False</property>
<property name="border_width">10</property>
<property name="title" translatable="yes">Configure feedback</property>
diff --git a/src/Makefile.am b/src/Makefile.am
index f09a4adc4..03639f9fe 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -93,7 +93,7 @@ SOURCES = \
gui/dialogPersonPopup.cs\
gui/dialogShortcuts.cs\
gui/dialogThreshold.cs\
- gui/repetitiveConditions.cs\
+ gui/feedback.cs\
gui/convertWeight.cs\
gui/genericWindow.cs\
gui/server.cs\
@@ -320,7 +320,7 @@ RESOURCES = \
../glade/preferences_win.glade \
../glade/query_server_window.glade \
../glade/repair_sub_event.glade \
- ../glade/repetitive_conditions.glade \
+ ../glade/feedback.glade \
../glade/report_window.glade \
../glade/run_type_add.glade \
../glade/session_upload.glade \
diff --git a/src/execute/event.cs b/src/execute/event.cs
index a47614de1..ff87edeaa 100644
--- a/src/execute/event.cs
+++ b/src/execute/event.cs
@@ -83,7 +83,7 @@ public class EventExecute
protected bool graphAllTypes;
protected bool graphAllPersons;
protected double progressbarLimit;
- protected RepetitiveConditionsWindow repetitiveConditionsWin;
+ protected FeedbackWindow feedbackWin;
protected ExecutingGraphData egd;
protected Gdk.Color colorBackground;
diff --git a/src/execute/jump.cs b/src/execute/jump.cs
index bc6200916..0799d4445 100644
--- a/src/execute/jump.cs
+++ b/src/execute/jump.cs
@@ -565,7 +565,7 @@ public class JumpRjExecute : JumpExecute
double limitAsDouble, bool jumpsLimited,
Chronopic cp, int pDN, bool allowFinishAfterTime,
bool volumeOn, Preferences.GstreamerTypes gstreamer,
- RepetitiveConditionsWindow repetitiveConditionsWin,
+ FeedbackWindow feedbackWin,
double progressbarLimit, ExecutingGraphData egd
)
{
@@ -593,7 +593,7 @@ public class JumpRjExecute : JumpExecute
this.allowFinishAfterTime = allowFinishAfterTime;
this.volumeOn = volumeOn;
this.gstreamer = gstreamer;
- this.repetitiveConditionsWin = repetitiveConditionsWin;
+ this.feedbackWin = feedbackWin;
this.progressbarLimit = progressbarLimit;
this.egd = egd;
diff --git a/src/execute/run.cs b/src/execute/run.cs
index bfb80e526..1807ec8f4 100644
--- a/src/execute/run.cs
+++ b/src/execute/run.cs
@@ -913,7 +913,7 @@ public class RunIntervalExecute : RunExecute
string wirelessPort, int wirelessBauds,
int pDN, bool metersSecondsPreferred,
bool volumeOn, Preferences.GstreamerTypes gstreamer,
- RepetitiveConditionsWindow repetitiveConditionsWin,
+ FeedbackWindow feedbackWin,
double progressbarLimit, ExecutingGraphData egd ,
Constants.DoubleContact checkDoubleContactMode, int checkDoubleContactTime,
bool speedStartArrival, bool measureReactionTime,
@@ -956,7 +956,7 @@ public class RunIntervalExecute : RunExecute
this.pDN = pDN;
this.volumeOn = volumeOn;
this.gstreamer = gstreamer;
- this.repetitiveConditionsWin = repetitiveConditionsWin;
+ this.feedbackWin = feedbackWin;
this.progressbarLimit = progressbarLimit;
this.egd = egd;
this.checkDoubleContactMode = checkDoubleContactMode;
diff --git a/src/gui/app1/chronojump.cs b/src/gui/app1/chronojump.cs
index f8e52bc0e..525c84a39 100644
--- a/src/gui/app1/chronojump.cs
+++ b/src/gui/app1/chronojump.cs
@@ -487,7 +487,7 @@ public partial class ChronoJumpWindow
ConfirmWindowJumpRun confirmWinJumpRun; //for deleting jumps and RJ jumps (and runs)
ReportWindow reportWin;
- RepetitiveConditionsWindow repetitiveConditionsWin;
+ FeedbackWindow feedbackWin;
GenericWindow genericWin;
ExecuteAutoWindow executeAutoWin;
@@ -682,11 +682,11 @@ public partial class ChronoJumpWindow
createComboSessionLoadTags(true);
- repetitiveConditionsWin = RepetitiveConditionsWindow.Create();
- //to have objects ok to be able to be readed before viewing the repetitiveConditionsWin
- repetitiveConditionsWin.View(Constants.BellModes.ENCODERGRAVITATORY, preferences,
encoderRhythm, false); //not viewWindow
- repetitiveConditionsWin.View(Constants.BellModes.FORCESENSOR, preferences, encoderRhythm,
false); //not viewWindow
- repetitiveConditionsWin.FakeButtonClose.Clicked += new
EventHandler(on_repetitive_conditions_closed);
+ feedbackWin = FeedbackWindow.Create();
+ //to have objects ok to be able to be readed before viewing the feedbackWin
+ feedbackWin.View(Constants.BellModes.ENCODERGRAVITATORY, preferences, encoderRhythm, false);
//not viewWindow
+ feedbackWin.View(Constants.BellModes.FORCESENSOR, preferences, encoderRhythm, false); //not
viewWindow
+ feedbackWin.FakeButtonClose.Clicked += new EventHandler(on_feedback_closed);
on_extra_window_multichronopic_test_changed(new object(), new EventArgs());
on_extra_window_pulses_test_changed(new object(), new EventArgs());
@@ -1680,7 +1680,7 @@ public partial class ChronoJumpWindow
PrepareJumpReactiveRealtimeCaptureGraph (selectedJumpRj.tvLast, selectedJumpRj.tcLast,
selectedJumpRj.TvString, selectedJumpRj.TcString,
selectedJumpRj.Type, selectedJumpRj.Description, //Description is personName
- preferences.volumeOn, preferences.gstreamer, repetitiveConditionsWin);
+ preferences.volumeOn, preferences.gstreamer, feedbackWin);
}
private void treeviewJumpsRjContextMenu(JumpRj myJump) {
@@ -3278,10 +3278,10 @@ public partial class ChronoJumpWindow
configInitFromPreferences();
- if(repetitiveConditionsWin != null)
+ if(feedbackWin != null)
{
- repetitiveConditionsWin.VolumeOn = preferences.volumeOn;
- repetitiveConditionsWin.Gstreamer = preferences.gstreamer;
+ feedbackWin.VolumeOn = preferences.volumeOn;
+ feedbackWin.Gstreamer = preferences.gstreamer;
}
try {
@@ -3975,17 +3975,17 @@ public partial class ChronoJumpWindow
Pixbuf pixbufBellInactive = new Pixbuf (null, Util.GetImagePath(false) +
"stock_bell_none.png");
if(
( (m == Constants.Modes.JUMPSSIMPLE || m == Constants.Modes.JUMPSREACTIVE) &&
- repetitiveConditionsWin.FeedbackActive(Constants.BellModes.JUMPS)) ||
+ feedbackWin.FeedbackActive(Constants.BellModes.JUMPS)) ||
( (m == Constants.Modes.RUNSSIMPLE || m == Constants.Modes.RUNSINTERVALLIC) &&
- repetitiveConditionsWin.FeedbackActive(Constants.BellModes.RUNS)) ||
+ feedbackWin.FeedbackActive(Constants.BellModes.RUNS)) ||
( m == Constants.Modes.FORCESENSOR &&
- repetitiveConditionsWin.FeedbackActive(Constants.BellModes.FORCESENSOR)) )
+ feedbackWin.FeedbackActive(Constants.BellModes.FORCESENSOR)) )
image_contacts_bell.Pixbuf = pixbufBellActive;
else
image_contacts_bell.Pixbuf = pixbufBellInactive;
if( (m == Constants.Modes.POWERGRAVITATORY || m == Constants.Modes.POWERINERTIAL)
- &&
repetitiveConditionsWin.FeedbackActive(Constants.BellModes.ENCODERGRAVITATORY) )
+ && feedbackWin.FeedbackActive(Constants.BellModes.ENCODERGRAVITATORY) )
image_encoder_bell.Pixbuf = pixbufBellActive;
else
image_encoder_bell.Pixbuf = pixbufBellInactive;
@@ -4775,7 +4775,7 @@ public partial class ChronoJumpWindow
m != Constants.Modes.FORCESENSOR)
return;
- repetitiveConditionsWin.View(getBellMode(m), preferences, encoderRhythm, true);
+ feedbackWin.View(getBellMode(m), preferences, encoderRhythm, true);
}
private void change_notebook_results_data()
@@ -5247,7 +5247,7 @@ public partial class ChronoJumpWindow
cp2016.CP, preferences.digitsNumber,
checkbutton_allow_finish_rj_after_time.Active,
preferences.volumeOn, preferences.gstreamer,
- repetitiveConditionsWin, progressbarLimit, egd);
+ feedbackWin, progressbarLimit, egd);
//suitable for limited by jump and time
//simulated always simulate limited by jumps
@@ -5537,7 +5537,7 @@ public partial class ChronoJumpWindow
cp2016.CP, photocellWirelessCapture, wirelessPort, wirelessBauds,
preferences.digitsNumber, preferences.metersSecondsPreferred,
preferences.volumeOn, preferences.gstreamer,
- repetitiveConditionsWin,
+ feedbackWin,
progressbarLimit, egd,
preferences.runIDoubleContactsMode,
preferences.runIDoubleContactsMS,
@@ -7675,7 +7675,7 @@ LogB.Debug("mc finished 5");
new About(progVersion, translator_credits);
}
- private void on_repetitive_conditions_closed(object o, EventArgs args)
+ private void on_feedback_closed(object o, EventArgs args)
{
//update bell color if feedback exists
Constants.Modes m = current_mode;
@@ -7684,7 +7684,8 @@ LogB.Debug("mc finished 5");
Constants.BellModes bellMode = getBellMode(m);
if(m == Constants.Modes.JUMPSREACTIVE || m == Constants.Modes.RUNSINTERVALLIC)
{
- if(repetitiveConditionsWin.FeedbackActive(bellMode))
+ // Update bell
+ if(feedbackWin.FeedbackActive(bellMode))
pixbuf = new Pixbuf (null, Util.GetImagePath(false) +
"stock_bell_active.png");
else
pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_none.png");
@@ -7693,18 +7694,20 @@ LogB.Debug("mc finished 5");
}
else if(m == Constants.Modes.POWERGRAVITATORY || m == Constants.Modes.POWERINERTIAL)
{
- if(repetitiveConditionsWin.FeedbackActive(bellMode))
+ // 1) Update bell
+ if(feedbackWin.FeedbackActive(bellMode))
pixbuf = new Pixbuf (null, Util.GetImagePath(false) +
"stock_bell_active.png");
else
pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_none.png");
image_encoder_bell.Pixbuf = pixbuf;
+ // 2) Update SQL and preferences object
Sqlite.Open();
//mainVariable
Constants.EncoderVariablesCapture mainVariable = Constants.SetEncoderVariablesCapture(
- repetitiveConditionsWin.GetMainVariable);
+ feedbackWin.GetMainVariable);
if( preferences.encoderCaptureMainVariable != mainVariable ) {
SqlitePreferences.Update("encoderCaptureMainVariable",
mainVariable.ToString(), true);
preferences.encoderCaptureMainVariable = mainVariable;
@@ -7713,7 +7716,7 @@ LogB.Debug("mc finished 5");
//secondaryVariable
Constants.EncoderVariablesCapture secondaryVariable =
Constants.SetEncoderVariablesCapture(
- repetitiveConditionsWin.GetSecondaryVariable);
+ feedbackWin.GetSecondaryVariable);
if( preferences.encoderCaptureSecondaryVariable != secondaryVariable ) {
SqlitePreferences.Update("encoderCaptureSecondaryVariable",
secondaryVariable.ToString(), true);
preferences.encoderCaptureSecondaryVariable = secondaryVariable;
@@ -7721,7 +7724,7 @@ LogB.Debug("mc finished 5");
string secondaryVariableStr = Constants.GetEncoderVariablesCapture(secondaryVariable);
//secondaryVariableShow
- bool secondaryVariableShow = repetitiveConditionsWin.GetSecondaryVariableShow;
+ bool secondaryVariableShow = feedbackWin.GetSecondaryVariableShow;
if( preferences.encoderCaptureSecondaryVariableShow != secondaryVariableShow ) {
SqlitePreferences.Update("encoderCaptureSecondaryVariableShow",
secondaryVariableShow.ToString(), true);
preferences.encoderCaptureSecondaryVariableShow = secondaryVariableShow;
@@ -7729,50 +7732,51 @@ LogB.Debug("mc finished 5");
if(! secondaryVariableShow)
secondaryVariableStr = "";
- if(preferences.encoderCaptureFeedbackEccon !=
repetitiveConditionsWin.GetEncoderCaptureFeedbackEccon) {
+ if(preferences.encoderCaptureFeedbackEccon !=
feedbackWin.GetEncoderCaptureFeedbackEccon) {
SqlitePreferences.Update(SqlitePreferences.EncoderCaptureFeedbackEccon,
-
repetitiveConditionsWin.GetEncoderCaptureFeedbackEccon.ToString(), true);
- preferences.encoderCaptureFeedbackEccon =
repetitiveConditionsWin.GetEncoderCaptureFeedbackEccon;
+ feedbackWin.GetEncoderCaptureFeedbackEccon.ToString(), true);
+ preferences.encoderCaptureFeedbackEccon =
feedbackWin.GetEncoderCaptureFeedbackEccon;
}
- if(preferences.encoderCaptureInertialEccOverloadMode !=
repetitiveConditionsWin.GetEncoderCaptureEccOverloadMode) {
+ if(preferences.encoderCaptureInertialEccOverloadMode !=
feedbackWin.GetEncoderCaptureEccOverloadMode) {
SqlitePreferences.Update(SqlitePreferences.EncoderCaptureInertialEccOverloadMode,
-
repetitiveConditionsWin.GetEncoderCaptureEccOverloadMode.ToString(), true);
- preferences.encoderCaptureInertialEccOverloadMode =
repetitiveConditionsWin.GetEncoderCaptureEccOverloadMode;
+ feedbackWin.GetEncoderCaptureEccOverloadMode.ToString(),
true);
+ preferences.encoderCaptureInertialEccOverloadMode =
feedbackWin.GetEncoderCaptureEccOverloadMode;
}
preferences.encoderCaptureMainVariableThisSetOrHistorical =
Preferences.PreferencesChange(
SqlitePreferences.EncoderCaptureMainVariableThisSetOrHistorical,
preferences.encoderCaptureMainVariableThisSetOrHistorical,
- repetitiveConditionsWin.EncoderRelativeToSet);
+ feedbackWin.EncoderRelativeToSet);
preferences.encoderCaptureMainVariableGreaterActive = Preferences.PreferencesChange(
SqlitePreferences.EncoderCaptureMainVariableGreaterActive,
preferences.encoderCaptureMainVariableGreaterActive,
- repetitiveConditionsWin.EncoderAutomaticHigherActive);
+ feedbackWin.EncoderAutomaticHigherActive);
preferences.encoderCaptureMainVariableGreaterValue = Preferences.PreferencesChange(
SqlitePreferences.EncoderCaptureMainVariableGreaterValue,
preferences.encoderCaptureMainVariableGreaterValue,
- repetitiveConditionsWin.EncoderAutomaticHigherValue);
+ feedbackWin.EncoderAutomaticHigherValue);
preferences.encoderCaptureMainVariableLowerActive = Preferences.PreferencesChange(
SqlitePreferences.EncoderCaptureMainVariableLowerActive,
preferences.encoderCaptureMainVariableLowerActive,
- repetitiveConditionsWin.EncoderAutomaticLowerActive);
+ feedbackWin.EncoderAutomaticLowerActive);
preferences.encoderCaptureMainVariableLowerValue = Preferences.PreferencesChange(
SqlitePreferences.EncoderCaptureMainVariableLowerValue,
preferences.encoderCaptureMainVariableLowerValue,
- repetitiveConditionsWin.EncoderAutomaticLowerValue);
+ feedbackWin.EncoderAutomaticLowerValue);
preferences.encoderCaptureShowLoss = Preferences.PreferencesChange(
SqlitePreferences.EncoderCaptureShowLoss,
preferences.encoderCaptureShowLoss,
- repetitiveConditionsWin.EncoderCaptureShowLoss);
+ feedbackWin.EncoderCaptureShowLoss);
Sqlite.Close();
+ // 3) Update treeview and graphs
//treeview_encoder should be updated (to colorize some cells)
//only if there was data
@@ -7786,8 +7790,8 @@ LogB.Debug("mc finished 5");
//also update the bars plot (to show colors depending on bells changes)
if(captureCurvesBarsData.Count > 0) {
- double mainVariableHigher =
repetitiveConditionsWin.GetMainVariableHigher(mainVariableStr);
- double mainVariableLower =
repetitiveConditionsWin.GetMainVariableLower(mainVariableStr);
+ double mainVariableHigher =
feedbackWin.GetMainVariableHigher(mainVariableStr);
+ double mainVariableLower =
feedbackWin.GetMainVariableLower(mainVariableStr);
//plotCurvesGraphDoPlot(mainVariableStr, mainVariableHigher,
mainVariableLower,
if(encoderGraphDoPlot != null)
@@ -7798,7 +7802,7 @@ LogB.Debug("mc finished 5");
secondaryVariableStr,
preferences.encoderCaptureShowLoss,
false,
findEccon(true),
- repetitiveConditionsWin,
+ feedbackWin,
encoderConfigurationCurrent.has_inertia,
configChronojump.PlaySoundsFromFile,
captureCurvesBarsData,
@@ -7813,7 +7817,7 @@ LogB.Debug("mc finished 5");
secondaryVariableStr,
preferences.encoderCaptureShowLoss,
false, //not capturing
findEccon(true),
- repetitiveConditionsWin,
+ feedbackWin,
encoderConfigurationCurrent.has_inertia,
configChronojump.PlaySoundsFromFile,
captureCurvesBarsData,
@@ -7831,20 +7835,23 @@ LogB.Debug("mc finished 5");
}
//rhythm
- encoderRhythm = repetitiveConditionsWin.Encoder_rhythm_get_values();
+ encoderRhythm = feedbackWin.Encoder_rhythm_get_values();
//updates preferences object and Sqlite preferences
preferences.UpdateEncoderRhythm(encoderRhythm);
}
else if(m == Constants.Modes.FORCESENSOR)
{
- if(repetitiveConditionsWin.FeedbackActive(bellMode))
+ // 1) Update bell
+ if(feedbackWin.FeedbackActive(bellMode))
pixbuf = new Pixbuf (null, Util.GetImagePath(false) +
"stock_bell_active.png");
else
pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_none.png");
image_contacts_bell.Pixbuf = pixbuf;
- Preferences.ForceSensorCaptureFeedbackActiveEnum feedbackActive =
repetitiveConditionsWin.GetForceSensorFeedback;
+ // 2) Update SQL and preferences object
+
+ Preferences.ForceSensorCaptureFeedbackActiveEnum feedbackActive =
feedbackWin.GetForceSensorFeedback;
if(preferences.forceSensorCaptureFeedbackActive != feedbackActive)
{
SqlitePreferences.Update(SqlitePreferences.ForceSensorCaptureFeedbackActive,
feedbackActive.ToString(), false);
@@ -7854,14 +7861,14 @@ LogB.Debug("mc finished 5");
//change the rest of values only if feedback is active
if(feedbackActive == Preferences.ForceSensorCaptureFeedbackActiveEnum.RECTANGLE)
{
- int feedbackAt = repetitiveConditionsWin.GetForceSensorFeedbackRectangleAt;
+ int feedbackAt = feedbackWin.GetForceSensorFeedbackRectangleAt;
if(preferences.forceSensorCaptureFeedbackAt != feedbackAt)
{
SqlitePreferences.Update(SqlitePreferences.ForceSensorCaptureFeedbackAt, feedbackAt.ToString(), false);
preferences.forceSensorCaptureFeedbackAt = feedbackAt;
}
- int feedbackRange =
repetitiveConditionsWin.GetForceSensorFeedbackRectangleRange;
+ int feedbackRange = feedbackWin.GetForceSensorFeedbackRectangleRange;
if(preferences.forceSensorCaptureFeedbackRange != feedbackRange)
{
SqlitePreferences.Update(SqlitePreferences.ForceSensorCaptureFeedbackRange, feedbackRange.ToString(), false);
@@ -7870,35 +7877,35 @@ LogB.Debug("mc finished 5");
}
else if(feedbackActive == Preferences.ForceSensorCaptureFeedbackActiveEnum.PATH)
{
- int feedbackPathMax = repetitiveConditionsWin.GetForceSensorFeedbackPathMax;
+ int feedbackPathMax = feedbackWin.GetForceSensorFeedbackPathMax;
if(preferences.forceSensorFeedbackPathMax != feedbackPathMax)
{
SqlitePreferences.Update(SqlitePreferences.ForceSensorFeedbackPathMax, feedbackPathMax.ToString(), false);
preferences.forceSensorFeedbackPathMax = feedbackPathMax;
}
- int feedbackPathMin = repetitiveConditionsWin.GetForceSensorFeedbackPathMin;
+ int feedbackPathMin = feedbackWin.GetForceSensorFeedbackPathMin;
if(preferences.forceSensorFeedbackPathMin != feedbackPathMin)
{
SqlitePreferences.Update(SqlitePreferences.ForceSensorFeedbackPathMin, feedbackPathMin.ToString(), false);
preferences.forceSensorFeedbackPathMin = feedbackPathMin;
}
- int feedbackPathMasters =
repetitiveConditionsWin.GetForceSensorFeedbackPathMasters;
+ int feedbackPathMasters = feedbackWin.GetForceSensorFeedbackPathMasters;
if(preferences.forceSensorFeedbackPathMasters != feedbackPathMasters)
{
SqlitePreferences.Update(SqlitePreferences.ForceSensorFeedbackPathMasters, feedbackPathMasters.ToString(),
false);
preferences.forceSensorFeedbackPathMasters = feedbackPathMasters;
}
- int feedbackPathMasterSeconds =
repetitiveConditionsWin.GetForceSensorFeedbackPathMasterSeconds;
+ int feedbackPathMasterSeconds =
feedbackWin.GetForceSensorFeedbackPathMasterSeconds;
if(preferences.forceSensorFeedbackPathMasterSeconds !=
feedbackPathMasterSeconds)
{
SqlitePreferences.Update(SqlitePreferences.ForceSensorFeedbackPathMasterSeconds,
feedbackPathMasterSeconds.ToString(), false);
preferences.forceSensorFeedbackPathMasterSeconds =
feedbackPathMasterSeconds;
}
- int feedbackPathLineWidth =
repetitiveConditionsWin.GetForceSensorFeedbackPathLineWidth;
+ int feedbackPathLineWidth = feedbackWin.GetForceSensorFeedbackPathLineWidth;
if(preferences.forceSensorFeedbackPathLineWidth != feedbackPathLineWidth)
{
SqlitePreferences.Update(SqlitePreferences.ForceSensorFeedbackPathLineWidth,
feedbackPathLineWidth.ToString(), false);
diff --git a/src/gui/encoderTreeviews.cs b/src/gui/encoderTreeviews.cs
index 7451206ba..436c8bd6a 100644
--- a/src/gui/encoderTreeviews.cs
+++ b/src/gui/encoderTreeviews.cs
@@ -155,7 +155,7 @@ public partial class ChronoJumpWindow
encoderCaptureListStore = new Gtk.ListStore (typeof (EncoderCurve));
-
repetitiveConditionsWin.ResetBestSetValue(RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK);
+ feedbackWin.ResetBestSetValue(FeedbackWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK);
bool eccPhase = true;
foreach (EncoderCurve curve in encoderCaptureCurves)
{
@@ -165,7 +165,7 @@ public partial class ChronoJumpWindow
preferences.encoderCaptureFeedbackEccon ==
Preferences.EncoderPhasesEnum.BOTH ||
preferences.encoderCaptureFeedbackEccon ==
Preferences.EncoderPhasesEnum.ECC && eccPhase ||
preferences.encoderCaptureFeedbackEccon ==
Preferences.EncoderPhasesEnum.CON && ! eccPhase )
- repetitiveConditionsWin.UpdateBestSetValue(curve);
+ feedbackWin.UpdateBestSetValue(curve);
eccPhase = ! eccPhase;
}
@@ -750,7 +750,7 @@ public partial class ChronoJumpWindow
encoderAnalyzeListStore = new Gtk.ListStore (typeof (EncoderCurve));
-
repetitiveConditionsWin.ResetBestSetValue(RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK);
+ feedbackWin.ResetBestSetValue(FeedbackWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK);
bool eccPhase = true;
foreach (EncoderCurve curve in encoderAnalyzeCurves)
{
@@ -760,7 +760,7 @@ public partial class ChronoJumpWindow
preferences.encoderCaptureFeedbackEccon ==
Preferences.EncoderPhasesEnum.BOTH ||
preferences.encoderCaptureFeedbackEccon ==
Preferences.EncoderPhasesEnum.ECC && eccPhase ||
preferences.encoderCaptureFeedbackEccon ==
Preferences.EncoderPhasesEnum.CON && ! eccPhase )
- repetitiveConditionsWin.UpdateBestSetValue(curve);
+ feedbackWin.UpdateBestSetValue(curve);
eccPhase = ! eccPhase;
}
@@ -1242,10 +1242,10 @@ public partial class ChronoJumpWindow
else {
string myColor = assignColor(
Convert.ToDouble(heightToCm),
- repetitiveConditionsWin.EncoderHeightHigher,
- repetitiveConditionsWin.EncoderHeightLower,
- repetitiveConditionsWin.EncoderHeightHigherValue,
- repetitiveConditionsWin.EncoderHeightLowerValue);
+ feedbackWin.EncoderHeightHigher,
+ feedbackWin.EncoderHeightLower,
+ feedbackWin.EncoderHeightHigherValue,
+ feedbackWin.EncoderHeightLowerValue);
if(myColor != "")
(cell as Gtk.CellRendererText).Foreground = myColor;
else
@@ -1264,17 +1264,17 @@ public partial class ChronoJumpWindow
(cell as Gtk.CellRendererText).Foreground = null; //will show default color
else {
Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
- string myColor = repetitiveConditionsWin.AssignColorAutomatic(
- RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
+ string myColor = feedbackWin.AssignColorAutomatic(
+ FeedbackWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
curve, Constants.MeanSpeed, phaseEnum);
if(myColor == "")
myColor = assignColor(
curve.MeanSpeedD,
- repetitiveConditionsWin.EncoderMeanSpeedHigher,
- repetitiveConditionsWin.EncoderMeanSpeedLower,
- repetitiveConditionsWin.EncoderMeanSpeedHigherValue,
- repetitiveConditionsWin.EncoderMeanSpeedLowerValue);
+ feedbackWin.EncoderMeanSpeedHigher,
+ feedbackWin.EncoderMeanSpeedLower,
+ feedbackWin.EncoderMeanSpeedHigherValue,
+ feedbackWin.EncoderMeanSpeedLowerValue);
if(myColor != "")
(cell as Gtk.CellRendererText).Foreground = myColor;
else
@@ -1294,17 +1294,17 @@ public partial class ChronoJumpWindow
(cell as Gtk.CellRendererText).Foreground = null; //will show default color
else {
Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
- string myColor = repetitiveConditionsWin.AssignColorAutomatic(
- RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
+ string myColor = feedbackWin.AssignColorAutomatic(
+ FeedbackWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
curve, Constants.MaxSpeed, phaseEnum);
if(myColor == "")
myColor = assignColor(
curve.MaxSpeedD,
- repetitiveConditionsWin.EncoderMaxSpeedHigher,
- repetitiveConditionsWin.EncoderMaxSpeedLower,
- repetitiveConditionsWin.EncoderMaxSpeedHigherValue,
- repetitiveConditionsWin.EncoderMaxSpeedLowerValue);
+ feedbackWin.EncoderMaxSpeedHigher,
+ feedbackWin.EncoderMaxSpeedLower,
+ feedbackWin.EncoderMaxSpeedHigherValue,
+ feedbackWin.EncoderMaxSpeedLowerValue);
if(myColor != "")
(cell as Gtk.CellRendererText).Foreground = myColor;
else
@@ -1332,17 +1332,17 @@ public partial class ChronoJumpWindow
(cell as Gtk.CellRendererText).Foreground = null; //will show default color
else {
Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
- string myColor = repetitiveConditionsWin.AssignColorAutomatic(
- RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
+ string myColor = feedbackWin.AssignColorAutomatic(
+ FeedbackWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
curve, Constants.MeanPower, phaseEnum);
if(myColor == "")
myColor = assignColor(
curve.MeanPowerD,
- repetitiveConditionsWin.EncoderPowerHigher,
- repetitiveConditionsWin.EncoderPowerLower,
- repetitiveConditionsWin.EncoderPowerHigherValue,
- repetitiveConditionsWin.EncoderPowerLowerValue);
+ feedbackWin.EncoderPowerHigher,
+ feedbackWin.EncoderPowerLower,
+ feedbackWin.EncoderPowerHigherValue,
+ feedbackWin.EncoderPowerLowerValue);
if(myColor != "")
(cell as Gtk.CellRendererText).Foreground = myColor;
else
@@ -1361,17 +1361,17 @@ public partial class ChronoJumpWindow
(cell as Gtk.CellRendererText).Foreground = null; //will show default color
else {
Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
- string myColor = repetitiveConditionsWin.AssignColorAutomatic(
- RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
+ string myColor = feedbackWin.AssignColorAutomatic(
+ FeedbackWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
curve, Constants.PeakPower, phaseEnum);
if(myColor == "")
myColor = assignColor(
curve.PeakPowerD,
- repetitiveConditionsWin.EncoderPeakPowerHigher,
- repetitiveConditionsWin.EncoderPeakPowerLower,
- repetitiveConditionsWin.EncoderPeakPowerHigherValue,
- repetitiveConditionsWin.EncoderPeakPowerLowerValue);
+ feedbackWin.EncoderPeakPowerHigher,
+ feedbackWin.EncoderPeakPowerLower,
+ feedbackWin.EncoderPeakPowerHigherValue,
+ feedbackWin.EncoderPeakPowerLowerValue);
if(myColor != "")
(cell as Gtk.CellRendererText).Foreground = myColor;
else
@@ -1407,17 +1407,17 @@ public partial class ChronoJumpWindow
(cell as Gtk.CellRendererText).Foreground = null; //will show default color
else {
Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
- string myColor = repetitiveConditionsWin.AssignColorAutomatic(
- RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
+ string myColor = feedbackWin.AssignColorAutomatic(
+ FeedbackWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
curve, Constants.MeanForce, phaseEnum);
if(myColor == "")
myColor = assignColor(
curve.MeanForceD,
- repetitiveConditionsWin.EncoderMeanForceHigher,
- repetitiveConditionsWin.EncoderMeanForceLower,
- repetitiveConditionsWin.EncoderMeanForceHigherValue,
- repetitiveConditionsWin.EncoderMeanForceLowerValue);
+ feedbackWin.EncoderMeanForceHigher,
+ feedbackWin.EncoderMeanForceLower,
+ feedbackWin.EncoderMeanForceHigherValue,
+ feedbackWin.EncoderMeanForceLowerValue);
if(myColor != "")
(cell as Gtk.CellRendererText).Foreground = myColor;
else
@@ -1436,17 +1436,17 @@ public partial class ChronoJumpWindow
(cell as Gtk.CellRendererText).Foreground = null; //will show default color
else {
Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
- string myColor = repetitiveConditionsWin.AssignColorAutomatic(
- RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
+ string myColor = feedbackWin.AssignColorAutomatic(
+ FeedbackWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
curve, Constants.MaxForce, phaseEnum);
if(myColor == "")
myColor = assignColor(
curve.MaxForceD,
- repetitiveConditionsWin.EncoderMaxForceHigher,
- repetitiveConditionsWin.EncoderMaxForceLower,
- repetitiveConditionsWin.EncoderMaxForceHigherValue,
- repetitiveConditionsWin.EncoderMaxForceLowerValue);
+ feedbackWin.EncoderMaxForceHigher,
+ feedbackWin.EncoderMaxForceLower,
+ feedbackWin.EncoderMaxForceHigherValue,
+ feedbackWin.EncoderMaxForceLowerValue);
if(myColor != "")
(cell as Gtk.CellRendererText).Foreground = myColor;
else
diff --git a/src/gui/eventExecute.cs b/src/gui/eventExecute.cs
index ce7b11c85..9567bad6a 100644
--- a/src/gui/eventExecute.cs
+++ b/src/gui/eventExecute.cs
@@ -499,14 +499,14 @@ public partial class ChronoJumpWindow
currentEventExecute.PrepareEventGraphJumpReactiveRealtimeCaptureObject.tcString,
currentEventExecute.PrepareEventGraphJumpReactiveRealtimeCaptureObject.type,
currentPerson.Name,
- preferences.volumeOn, preferences.gstreamer,
repetitiveConditionsWin);
+ preferences.volumeOn, preferences.gstreamer,
feedbackWin);
}
else if(selectedJumpRj != null)
PrepareJumpReactiveRealtimeCaptureGraph (selectedJumpRj.tvLast,
selectedJumpRj.tcLast,
selectedJumpRj.TvString, selectedJumpRj.TcString,
selectedJumpRj.Type, selectedJumpRj.Description,
//Description is person.Name
- preferences.volumeOn, preferences.gstreamer,
repetitiveConditionsWin);
+ preferences.volumeOn, preferences.gstreamer, feedbackWin);
} else if (current_mode == Constants.Modes.RUNSINTERVALLIC)
{
if(currentEventExecute != null && currentEventExecute.IsThreadRunning())
@@ -669,7 +669,7 @@ public partial class ChronoJumpWindow
public void PrepareJumpReactiveRealtimeCaptureGraph (double lastTv, double lastTc, string tvString,
string tcString,
string type, string personName,
- bool volumeOn, Preferences.GstreamerTypes gstreamer, RepetitiveConditionsWindow
repetitiveConditionsWin)
+ bool volumeOn, Preferences.GstreamerTypes gstreamer, FeedbackWindow feedbackWin)
{
if(currentPerson == null)
return;
@@ -1865,7 +1865,7 @@ public partial class ChronoJumpWindow
currentEventExecute.PrepareEventGraphJumpReactiveRealtimeCaptureObject.tcString,
currentEventExecute.PrepareEventGraphJumpReactiveRealtimeCaptureObject.type,
currentPerson.Name,
- preferences.volumeOn, preferences.gstreamer,
repetitiveConditionsWin);
+ preferences.volumeOn, preferences.gstreamer,
feedbackWin);
}
break;
case EventType.Types.RUN:
@@ -3463,8 +3463,8 @@ public class CairoPaintBarplotPreEncoder : CairoPaintBarsPre
}
//select pen color for bars and sounds
- string myColor = pegbe.repetitiveConditionsWin.AssignColorAutomatic(
- RepetitiveConditionsWindow.BestSetValueEnum.CAPTURE_MAIN_VARIABLE,
ebd.GetValue(pegbe.mainVariable), phaseEnum);
+ string myColor = pegbe.feedbackWin.AssignColorAutomatic(
+ FeedbackWindow.BestSetValueEnum.CAPTURE_MAIN_VARIABLE,
ebd.GetValue(pegbe.mainVariable), phaseEnum);
bool discarded = false;
if(pegbe.hasInertia) {
diff --git a/src/gui/repetitiveConditions.cs b/src/gui/feedback.cs
similarity index 97%
rename from src/gui/repetitiveConditions.cs
rename to src/gui/feedback.cs
index fa7f0dd8f..61a7a84a5 100644
--- a/src/gui/repetitiveConditions.cs
+++ b/src/gui/feedback.cs
@@ -24,9 +24,9 @@ using Gdk;
using Glade;
using Mono.Unix;
-public class RepetitiveConditionsWindow
+public class FeedbackWindow
{
- [Widget] Gtk.Window repetitive_conditions;
+ [Widget] Gtk.Window feedback;
[Widget] Gtk.Notebook notebook_main;
//[Widget] Gtk.ScrolledWindow scrolled_conditions;
@@ -213,19 +213,19 @@ public class RepetitiveConditionsWindow
private double bestSetValueAutomaticFeedback;
private bool update_checkbuttons_encoder_automatic;
- static RepetitiveConditionsWindow RepetitiveConditionsWindowBox;
+ static FeedbackWindow FeedbackWindowBox;
- RepetitiveConditionsWindow ()
+ FeedbackWindow ()
{
Glade.XML gladeXML;
- gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "repetitive_conditions.glade",
"repetitive_conditions", "chronojump");
+ gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "feedback.glade", "feedback",
"chronojump");
gladeXML.Autoconnect(this);
//don't show until View is called
- repetitive_conditions.Hide ();
+ feedback.Hide ();
//put an icon to window
- UtilGtk.IconWindow(repetitive_conditions);
+ UtilGtk.IconWindow(feedback);
FakeButtonClose = new Gtk.Button();
@@ -241,26 +241,26 @@ public class RepetitiveConditionsWindow
label_rhythm_tab.Text = Catalog.GetString("Rhythm") + " / " + Catalog.GetString("Protocol");
}
- static public RepetitiveConditionsWindow Create ()
+ static public FeedbackWindow Create ()
{
- if (RepetitiveConditionsWindowBox == null) {
- RepetitiveConditionsWindowBox = new RepetitiveConditionsWindow ();
+ if (FeedbackWindowBox == null) {
+ FeedbackWindowBox = new FeedbackWindow ();
}
//don't show until View is called
- //RepetitiveConditionsWindowBox.repetitive_conditions.Hide ();
+ //FeedbackWindowBox.feedback.Hide ();
- return RepetitiveConditionsWindowBox;
+ return FeedbackWindowBox;
}
public void View (Constants.BellModes bellMode, Preferences preferences, EncoderRhythm encoderRhythm,
bool viewWindow)
{
//when user "deleted_event" the window
- if (RepetitiveConditionsWindowBox == null) {
- RepetitiveConditionsWindowBox = new RepetitiveConditionsWindow ();
+ if (FeedbackWindowBox == null) {
+ FeedbackWindowBox = new FeedbackWindow ();
}
- RepetitiveConditionsWindowBox.update_checkbuttons_encoder_automatic = true;
- RepetitiveConditionsWindowBox.showWidgets(bellMode,
+ FeedbackWindowBox.update_checkbuttons_encoder_automatic = true;
+ FeedbackWindowBox.showWidgets(bellMode,
preferences.encoderCaptureMainVariable,
preferences.encoderCaptureSecondaryVariable,
preferences.encoderCaptureSecondaryVariableShow,
preferences.encoderCaptureInertialEccOverloadMode,
@@ -286,13 +286,13 @@ public class RepetitiveConditionsWindow
{
//manage window color
if(! Config.UseSystemColor)
- UtilGtk.WindowColor(RepetitiveConditionsWindowBox.repetitive_conditions,
Config.ColorBackground);
+ UtilGtk.WindowColor(FeedbackWindowBox.feedback, Config.ColorBackground);
- RepetitiveConditionsWindowBox.repetitive_conditions.Show ();
+ FeedbackWindowBox.feedback.Show ();
}
- RepetitiveConditionsWindowBox.volumeOn = preferences.volumeOn;
- RepetitiveConditionsWindowBox.gstreamer = preferences.gstreamer;
+ FeedbackWindowBox.volumeOn = preferences.volumeOn;
+ FeedbackWindowBox.gstreamer = preferences.gstreamer;
}
void showWidgets(Constants.BellModes bellMode,
@@ -575,15 +575,15 @@ public class RepetitiveConditionsWindow
void on_button_close_clicked (object o, EventArgs args)
{
- RepetitiveConditionsWindowBox.repetitive_conditions.Hide();
+ FeedbackWindowBox.feedback.Hide();
FakeButtonClose.Click();
- //RepetitiveConditionsWindowBox = null;
+ //FeedbackWindowBox = null;
}
void on_delete_event (object o, DeleteEventArgs args)
{
- //RepetitiveConditionsWindowBox.repetitive_conditions.Hide();
- //RepetitiveConditionsWindowBox = null;
+ //FeedbackWindowBox.feedback.Hide();
+ //FeedbackWindowBox = null;
button_close.Click();
args.RetVal = true;
diff --git a/src/gui/networks.cs b/src/gui/networks.cs
index 259f29d2d..031b7435c 100644
--- a/src/gui/networks.cs
+++ b/src/gui/networks.cs
@@ -1206,17 +1206,17 @@ public partial class ChronoJumpWindow
spin_encoder_extra_weight.Value = Convert.ToDouble(task.Load);
if(task.Speed > 0) {
- repetitiveConditionsWin.EncoderMeanSpeedHigherValue = task.Speed;
- repetitiveConditionsWin.EncoderMeanSpeedHigher = true;
- repetitiveConditionsWin.EncoderMeanSpeedLowerValue = task.Speed / 2;
- repetitiveConditionsWin.EncoderMeanSpeedHigher = true;
- repetitiveConditionsWin.Encoder_show_manual_feedback = true;
- repetitiveConditionsWin.Notebook_encoder_conditions_page = 1; //speed
+ feedbackWin.EncoderMeanSpeedHigherValue = task.Speed;
+ feedbackWin.EncoderMeanSpeedHigher = true;
+ feedbackWin.EncoderMeanSpeedLowerValue = task.Speed / 2;
+ feedbackWin.EncoderMeanSpeedHigher = true;
+ feedbackWin.Encoder_show_manual_feedback = true;
+ feedbackWin.Notebook_encoder_conditions_page = 1; //speed
pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_active.png");
} else {
- repetitiveConditionsWin.EncoderMeanSpeedHigher = false;
- repetitiveConditionsWin.EncoderMeanSpeedLower = false;
- repetitiveConditionsWin.Encoder_show_manual_feedback = false;
+ feedbackWin.EncoderMeanSpeedHigher = false;
+ feedbackWin.EncoderMeanSpeedLower = false;
+ feedbackWin.Encoder_show_manual_feedback = false;
pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_none.png");
}
image_encoder_bell.Pixbuf = pixbuf;
diff --git a/src/gui/usefulObjects.cs b/src/gui/usefulObjects.cs
index 4a0e44bb1..d9f4f52ed 100644
--- a/src/gui/usefulObjects.cs
+++ b/src/gui/usefulObjects.cs
@@ -394,7 +394,7 @@ public class PrepareEventGraphBarplotEncoder
public bool showLoss;
public bool capturing;
public string eccon;
- public RepetitiveConditionsWindow repetitiveConditionsWin;
+ public FeedbackWindow feedbackWin;
public bool hasInertia;
public bool playSoundsFromFile;
public ArrayList data9Variables;
@@ -413,7 +413,7 @@ public class PrepareEventGraphBarplotEncoder
string mainVariable, double mainVariableHigher, double mainVariableLower,
string secondaryVariable, bool showLoss,
bool capturing, string eccon,
- RepetitiveConditionsWindow repetitiveConditionsWin,
+ FeedbackWindow feedbackWin,
bool hasInertia, bool playSoundsFromFile,
ArrayList data9Variables, Gtk.ListStore encoderCaptureListStore,
bool relativeToSet,
@@ -428,7 +428,7 @@ public class PrepareEventGraphBarplotEncoder
this.showLoss = showLoss;
this.capturing = capturing;
this.eccon = eccon;
- this.repetitiveConditionsWin = repetitiveConditionsWin;
+ this.feedbackWin = feedbackWin;
this.hasInertia = hasInertia;
this.playSoundsFromFile = playSoundsFromFile;
this.data9Variables = data9Variables;
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/gui/app1/encoder.cs b/src/gui/app1/encoder.cs
index b3985a0c3..2874f00a3 100644
--- a/src/gui/app1/encoder.cs
+++ b/src/gui/app1/encoder.cs
@@ -679,7 +679,7 @@ public partial class ChronoJumpWindow
private void on_button_encoder_bells_clicked(object o, EventArgs args)
{
- repetitiveConditionsWin.View(getBellMode(current_mode), preferences, encoderRhythm, true);
+ feedbackWin.View(getBellMode(current_mode), preferences, encoderRhythm, true);
}
/*
@@ -1806,7 +1806,7 @@ public partial class ChronoJumpWindow
* maxPowerIntersession it's defined (Sqlite select) on capture and after
capture
* if we have not captured yet, just Sqlite select now
*/
- if(! repetitiveConditionsWin.EncoderRelativeToSet)
+ if(! feedbackWin.EncoderRelativeToSet)
findMaxPowerSpeedForceIntersession();
spin_encoder_extra_weight.Value =
Convert.ToDouble(Util.ChangeDecimalSeparator(eSQL.extraWeight));
@@ -5877,8 +5877,8 @@ public partial class ChronoJumpWindow
string secondaryVariable =
Constants.GetEncoderVariablesCapture(preferences.encoderCaptureSecondaryVariable);
if(! preferences.encoderCaptureSecondaryVariableShow)
secondaryVariable = "";
- double mainVariableHigher =
repetitiveConditionsWin.GetMainVariableHigher(mainVariable);
- double mainVariableLower = repetitiveConditionsWin.GetMainVariableLower(mainVariable);
+ double mainVariableHigher = feedbackWin.GetMainVariableHigher(mainVariable);
+ double mainVariableLower = feedbackWin.GetMainVariableLower(mainVariable);
if(encoderGraphDoPlot != null)
encoderGraphDoPlot.Start(
@@ -5886,7 +5886,7 @@ public partial class ChronoJumpWindow
secondaryVariable, preferences.encoderCaptureShowLoss,
false, //not capturing
findEccon(true),
- repetitiveConditionsWin,
+ feedbackWin,
encoderConfigurationCurrent.has_inertia,
configChronojump.PlaySoundsFromFile,
captureCurvesBarsData,
@@ -5901,7 +5901,7 @@ public partial class ChronoJumpWindow
secondaryVariable, preferences.encoderCaptureShowLoss,
false, //not capturing
findEccon(true),
- repetitiveConditionsWin,
+ feedbackWin,
encoderConfigurationCurrent.has_inertia,
configChronojump.PlaySoundsFromFile,
captureCurvesBarsData,
@@ -6759,8 +6759,8 @@ public partial class ChronoJumpWindow
//if(plotCurvesBars) {
string mainVariable =
Constants.GetEncoderVariablesCapture(preferences.encoderCaptureMainVariable);
- double mainVariableHigher =
repetitiveConditionsWin.GetMainVariableHigher(mainVariable);
- double mainVariableLower =
repetitiveConditionsWin.GetMainVariableLower(mainVariable);
+ double mainVariableHigher = feedbackWin.GetMainVariableHigher(mainVariable);
+ double mainVariableLower = feedbackWin.GetMainVariableLower(mainVariable);
string secondaryVariable =
Constants.GetEncoderVariablesCapture(preferences.encoderCaptureSecondaryVariable);
if(! preferences.encoderCaptureSecondaryVariableShow)
secondaryVariable = "";
@@ -6776,7 +6776,7 @@ public partial class ChronoJumpWindow
secondaryVariable, preferences.encoderCaptureShowLoss,
true, //capturing
findEccon(true),
- repetitiveConditionsWin,
+ feedbackWin,
encoderConfigurationCurrent.has_inertia,
configChronojump.PlaySoundsFromFile,
captureCurvesBarsData,
@@ -6791,7 +6791,7 @@ public partial class ChronoJumpWindow
secondaryVariable, preferences.encoderCaptureShowLoss,
true, //capturing
findEccon(true),
- repetitiveConditionsWin,
+ feedbackWin,
encoderConfigurationCurrent.has_inertia,
configChronojump.PlaySoundsFromFile,
captureCurvesBarsData,
@@ -7330,8 +7330,8 @@ public partial class ChronoJumpWindow
//variables for plotting curves bars graph
string mainVariable =
Constants.GetEncoderVariablesCapture(preferences.encoderCaptureMainVariable);
- double mainVariableHigher =
repetitiveConditionsWin.GetMainVariableHigher(mainVariable);
- double mainVariableLower =
repetitiveConditionsWin.GetMainVariableLower(mainVariable);
+ double mainVariableHigher = feedbackWin.GetMainVariableHigher(mainVariable);
+ double mainVariableLower = feedbackWin.GetMainVariableLower(mainVariable);
string secondaryVariable =
Constants.GetEncoderVariablesCapture(preferences.encoderCaptureSecondaryVariable);
if(! preferences.encoderCaptureSecondaryVariableShow)
secondaryVariable = "";
@@ -7378,7 +7378,7 @@ public partial class ChronoJumpWindow
secondaryVariable, preferences.encoderCaptureShowLoss,
false, //not capturing
findEccon(true),
- repetitiveConditionsWin,
+ feedbackWin,
encoderConfigurationCurrent.has_inertia,
configChronojump.PlaySoundsFromFile,
captureCurvesBarsData,
@@ -7393,7 +7393,7 @@ public partial class ChronoJumpWindow
secondaryVariable, preferences.encoderCaptureShowLoss,
false, //not capturing
findEccon(true),
- repetitiveConditionsWin,
+ feedbackWin,
encoderConfigurationCurrent.has_inertia,
configChronojump.PlaySoundsFromFile,
captureCurvesBarsData,
@@ -7825,7 +7825,7 @@ public partial class ChronoJumpWindow
* mark their rows (meaning saved)
* also if updateSQLRecords, then update SQL meanPower of the curve
*
* This method is called by on_repetitive_conditions_closed, and finishPulsebar
*/
private void findAndMarkSavedCurves(bool dbconOpened, bool updateSQLRecords)
{
@@ -7825,7 +7825,7 @@ public partial class ChronoJumpWindow
* also if updateSQLRecords, then update SQL meanPower of the curve
*
- * This method is called by on_repetitive_conditions_closed, and finishPulsebar
+ * This method is called by on_feedback_closed, and finishPulsebar
*/
private void findAndMarkSavedCurves(bool dbconOpened, bool updateSQLRecords)
diff --git a/src/gui/encoderGraphObjects.cs b/src/gui/encoderGraphObjects.cs
index c6ad94e7b..66a9e98dc 100644
--- a/src/gui/encoderGraphObjects.cs
+++ b/src/gui/encoderGraphObjects.cs
@@ -41,7 +41,7 @@ public class EncoderGraphDoPlot
private bool showLoss;
private bool capturing;
private string eccon;
- private RepetitiveConditionsWindow repetitiveConditionsWin;
+ private FeedbackWindow feedbackWin;
private bool hasInertia;
private bool playSoundsFromFile;
private ArrayList data9Variables;
@@ -147,7 +147,7 @@ public class EncoderGraphDoPlot
string mainVariable, double mainVariableHigher, double mainVariableLower,
string secondaryVariable, bool showLoss,
bool capturing, string eccon,
- RepetitiveConditionsWindow repetitiveConditionsWin,
+ FeedbackWindow feedbackWin,
bool hasInertia, bool playSoundsFromFile,
ArrayList data9Variables, Gtk.ListStore encoderCaptureListStore,
bool relativeToSet,
@@ -160,7 +160,7 @@ public class EncoderGraphDoPlot
this.showLoss = showLoss;
this.capturing = capturing;
this.eccon = eccon;
- this.repetitiveConditionsWin = repetitiveConditionsWin;
+ this.feedbackWin = feedbackWin;
this.hasInertia = hasInertia;
this.playSoundsFromFile = playSoundsFromFile;
this.data9Variables = data9Variables;
@@ -457,9 +457,9 @@ public class EncoderGraphDoPlot
if(d > maxAbsoluteSecondary)
maxAbsoluteSecondary = d;
-
repetitiveConditionsWin.ResetBestSetValue(RepetitiveConditionsWindow.BestSetValueEnum.CAPTURE_MAIN_VARIABLE);
- repetitiveConditionsWin.UpdateBestSetValue(
- RepetitiveConditionsWindow.BestSetValueEnum.CAPTURE_MAIN_VARIABLE,
maxAbsoluteForCalc);
+ feedbackWin.ResetBestSetValue(FeedbackWindow.BestSetValueEnum.CAPTURE_MAIN_VARIABLE);
+ feedbackWin.UpdateBestSetValue(
+ FeedbackWindow.BestSetValueEnum.CAPTURE_MAIN_VARIABLE, maxAbsoluteForCalc);
int textWidth = 1;
int textHeight = 1;
@@ -643,8 +643,8 @@ public class EncoderGraphDoPlot
}
//select pen color for bars and sounds
- string myColor = repetitiveConditionsWin.AssignColorAutomatic(
- RepetitiveConditionsWindow.BestSetValueEnum.CAPTURE_MAIN_VARIABLE, d,
phaseEnum);
+ string myColor = feedbackWin.AssignColorAutomatic(
+ FeedbackWindow.BestSetValueEnum.CAPTURE_MAIN_VARIABLE, d, phaseEnum);
bool discarded = false;
if(hasInertia) {
@@ -822,7 +822,7 @@ public class EncoderGraphDoPlot
//paint secondary variable circle and lines
//but do not do it if user do not want to show it from repetitiveConditionsWindow
if(dataSecondary.Count > 0)
{
double dSecondary = Convert.ToDouble(dataSecondary[count]);
@@ -822,7 +822,7 @@ public class EncoderGraphDoPlot
//paint secondary variable circle and lines
- //but do not do it if user do not want to show it from repetitiveConditionsWindow
+ //but do not do it if user do not want to show it from feedbackWindow
if(dataSecondary.Count > 0)
{